#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 descriptive
version:              0.9.5
visibility:           public
id:                   descriptive-0.9.5-GO15sppKE39D4jRdnDGYTF
key:                  descriptive-0.9.5-GO15sppKE39D4jRdnDGYTF
license:              BSD-3-Clause
copyright:            2015 Chris Done
maintainer:           chrisdone@gmail.com
author:               Chris Done
stability:            Experimental
homepage:             https://github.com/chrisdone/descriptive
synopsis:
    Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.

description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.

category:             Parsing
abi:                  95a71ab9b3089e9bfa109b9ec3ff00db
exposed:              True
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.JSON Descriptive.Options

hidden-modules:       Descriptive.Internal
import-dirs:          /usr/lib/ghc-8.10.5/site-local/descriptive-0.9.5
library-dirs:         /usr/lib/ghc-8.10.5/site-local/descriptive-0.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/descriptive-0.9.5
hs-libraries:         HSdescriptive-0.9.5-GO15sppKE39D4jRdnDGYTF
depends:
    aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ base-4.14.2.0
    bifunctors-5.5.11-5WHPU2oStxP1cNabXCzf9E containers-0.6.4.1
    mtl-2.2.2 scientific-0.3.7.0-Fi0gRGhsiJ35wgbCjOXuHX text-1.2.4.1
    transformers-0.5.6.2 vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:   /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html:         /usr/share/doc/haskell-descriptive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

